@@ -192,9 +192,11 @@ class RandomForestImputer(DataPreprocessingMixin, ModelMixin, PlotMixin):
         self._isolate_samples_with_no_target_value(title="[ISOLATING SAMPLES"\
                                                     "WITH NO TARGET VALUE]: ")
         self._separate_features_and_target_variable()  
-        self._predict_feature_type(title="[PREDICTING FEATURE TYPE]: ")
-        self._predict_target_variable_type(title="[PREDICTING TARGET VARIABLE"\
-                                            "TYPE]: ") 
+        if not self._predict_feature_type:
+            self._predict_feature_type(title="[PREDICTING FEATURE TYPE]: ")
+        if not self._predict_target_variable_type:
+            self._predict_target_variable_type(title="[PREDICTING TARGET VARIABLE"\
+                                                       "TYPE]: ") 
         self._retrieve_nan_coordinates(title="[RETRIEVING NAN COORDINATES]: ")
         self._make_initial_guesses(title="[MAKING INITIAL GUESSES]: ")
         self._encode_target_variable()
@@ -239,6 +241,3 @@ class RandomForestImputer(DataPreprocessingMixin, ModelMixin, PlotMixin):
         self._save_new_dataset(final_dataset, path_to_save_dataset)
         return  final_dataset 
 
-    
-    
-    
